@@ -1,6 +1,5 @@
 import logging
 from email.mime.application import MIMEApplication
-from django.template.loader import render_to_string
 import boto3
 from botocore.exceptions import ClientError
 from django.conf import settings
@@ -62,18 +61,21 @@ def send_notifications(email, sender, email_configuration):
 
     # The full path to the file that will be attached to the email.
     ATTACHMENT = LOG_PATH
-    cover = email_configuration.get('Banner')
+    cover = settings.MEDIA_ROOT + '/' + email_configuration.get('Banner')
     logger.info(cover)
-    logo = email_configuration.get('Logo')
+    logo = settings.MEDIA_ROOT + '/' + email_configuration.get('Logo')
     logger.info(logo)
-    paragraph = email_configuration.get('Email_Content')
-    logger.info(paragraph)
+
     # # The HTML body of the email.
     file_name = email_configuration.get('HTML_File')
-    # email_html = open(file_name)
-    BODY_HTML = open('media/' + file_name).read().format(cover=cover,
-                                                         logo=logo,
-                                                         paragraph=paragraph)
+    logger.info(file_name)
+    BODY_HTML = open('media/' + file_name).read().format(
+        cover=cover, logo=logo,
+        paragraph=email_configuration.get('Email_Content'),
+        signature=email_configuration.get('Signature'),
+        email_us=email_configuration.get('Email_Us'),
+        faq_url=email_configuration.get('FAQ_URL'),
+        unsubscribe=email_configuration.get('Unsubscribe_Email_ID'))
     # Define the attachment part and encode it using MIMEApplication.
     att = MIMEApplication(open(ATTACHMENT, 'rb').read())
 
