@@ -53,10 +53,20 @@ class EmailConfiguration(TimeStampedModel):
     Banner = models.ImageField(upload_to='banner_pic', default='banner.jpg',
                                help_text="Please upload your banner here")
 
-    Log_path = models.CharField(max_length=200, null=True)
-
     Email_Content = models.TextField(max_length=200, null=True)
 
+    Signature = models.TextField(max_length=200, null=True)
+
+    Email_Us = models.EmailField(max_length=254,
+                                 help_text='Enter email address')
+
+    FAQ_URL = models.CharField(max_length=200, null=True)
+
+    Unsubscribe_Email_ID = models.EmailField(
+        max_length=254,
+        help_text='Enter email address')
+    Log_path = models.CharField(max_length=200, null=True)
+
     HTML_File = models.FileField(upload_to='HTML_files',
                                  help_text='Upload the html file')
 
